#include <board.h>
#include <lcd.h>
#include <delay.h>
#include <event.h>
#include <serial.h>
#include <spi.h>
#include <stdlib.h>
#include "at45db321d.h"
#include "dac.h"

#define DF_READ_MANUFACTURER_AND_DEVICE_ID   0x9F
#define AUDIO_MAN_ID 0x1F

uint8_t audio_init(void)
{
	int8_t temp[2];

	flashmem_init();
	dac_init();
	microdelay_init();

	/* Audio board initialization */
	ReadManufacturerID(temp);
	if (temp[0] != AUDIO_MAN_ID) {
		printf("Error in audio board...!\n");
		printf("%2X != %2X", AUDIO_MAN_ID, temp[0]);
		return 0;
	} else {
		printf("Audio board connected...!\n");
		return 1;
	}
}

int main(void)
{
	uint8_t buff[528] = {0};
	uint32_t page_address;
	uint32_t pointer;
	uint8_t counter;

	board_init();
	systick_init();
	spi_init(30000,
		SPI_CPOL_IDLE_LOW,
		SPI_CPHASE_LEAD_EDGE,
		SPI_ENDIAN_MSB_FIRST);
	serial_init_with_fifo(buff, 200);
	lcd_init();
	board_stdout(LCD_STDOUT);
	delay_init();
	dac_init();

	if (!audio_init())
		return 1;

	pointer = 0;
	counter = 0;
	page_address = 0;
	while (1) {
		if (NULL == xreceive(&buff[pointer])) {
			PageWrite(page_address, 0, buff);
			printf("Tot pages:%d\n", page_address);
			printf("Data received successfully.");
			return 0;
		} else {
			counter++;
			pointer += 128;
			if (counter == 4) {
				PageWrite(page_address, 0, buff);
				page_address++;
				counter = 0;
				pointer = 0;
			}
		}
	}
}
