#include "microdelay.h"

/*****************************************************************************
 ** Function name:		microdelay_init
 **
 ** Descriptions:		Intialize delay Timer
 **
 ** parameters:			None
 **
 ** Returned value:		None
 **
 *****************************************************************************/
void microdelay_init(void)
{
	volatile uint32_t *sysclock = (uint32_t *) SYSAHBCLKCTRL;

	/* Enable Timer Clock */
	*sysclock |= (1 << 9);
}



/*****************************************************************************
 ** Function name:		microdelay
 **
 ** Descriptions:		Produce delay between each Sample corresponding
 **                             to the sample rate
 **
 ** parameters:			srate(Sampling rate)
 **
 ** Returned value:		None
 **
 *****************************************************************************/

void microdelay(uint32_t srate)
{
	volatile uint32_t *tcr = (uint32_t *) TMR32B0TCR;
	volatile uint32_t *mcr = (uint32_t *) TMR32B0MCR;
	volatile uint32_t *mr0 = (uint32_t *) TMR32B0MR0;

	switch (srate) {
	case 8:
		*mr0 = 8928 - RWDELAY;  /* 8kHz */
		break;
	case 11:
		*mr0 = 6478 - RWDELAY;  /* 11kHz */
		break;
	case 16:
		*mr0 = 4464 - RWDELAY;  /* 16kHz */
	}


	*tcr = 2;     /* reset timer */
	*mcr = 4;     /* set mcr to reset tc when tc matches with mr0; */
	*tcr = 1;     /* start timer */
	while ((*tcr) & 0x00000001)
		;
}
