#include <board.h>
#include <event.h>
#include <spi.h>
#include <lcd.h>
#include "at45db321d.h"
#include "microdelay.h"
#include "dac.h"

#define DF_READ_MANUFACTURER_AND_DEVICE_ID   0x9F
#define AUDIO_MAN_ID 0x1F

static unsigned int	   paddress;
static unsigned short int  baddress;
static const unsigned int  eadd     = 4000;
static const unsigned char srate    = 8;
static const unsigned char bits     = 8;
static bool		   state    = true;

void play(void)
{
	while (true) {
		if (state == false)
			break;
		if ((paddress >  eadd) && (baddress == 0)) {
			state = false;
			break;
		} else {
			dac_write(ByteRead(paddress, baddress));
			baddress++;
			if (baddress == PGSIZE) {
				baddress = 0;
				paddress++;
			}
			microdelay(srate);
			event_poll_once();
		}
	}
}

uint8_t audio_init(void)
{
	int8_t temp[2];

	/* Audio board initialization */
	ReadManufacturerID(temp);
	if (temp[0] != AUDIO_MAN_ID) {
		lcd_puts("Error in audio board...!\n");
		printf("%2X != %2X", AUDIO_MAN_ID, temp[0]);
		return 0;
	} else {
		lcd_puts("Audio board connected.\n");
		return 1;
	}
}

int main(void)
{
	board_init();
	lcd_init();
	systick_init();
	spi_init(30000,
		SPI_CPOL_IDLE_LOW,
		SPI_CPHASE_LEAD_EDGE,
		SPI_ENDIAN_MSB_FIRST);
	flashmem_init();
	dac_init();
	microdelay_init();

	if (!audio_init())
		return 1;

	play();

	return 0;
}
